from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File

Backspin_V0_1_0 = CommandToolBuilder(tool="backspin", base_command=["backspin"], inputs=[ToolInput(tag="in_i", input_type=Boolean(optional=True), prefix="-i", doc=InputDocumentation(doc="[inputfile]")), ToolInput(tag="in_input", input_type=Boolean(optional=True), prefix="--input", doc=InputDocumentation(doc="=[inputfile]\nPath of the cef formatted tab delimited file.\nRows should be genes and columns single cells/samples.\nFor further information on the cef format visit:\nhttps://github.com/linnarsson-lab/ceftools")), ToolInput(tag="in_o", input_type=Boolean(optional=True), prefix="-o", doc=InputDocumentation(doc="[outputfile]")), ToolInput(tag="in_output", input_type=File(optional=True), prefix="--output", doc=InputDocumentation(doc="=[outputfile]\nThe name of the file to which the output will be written")), ToolInput(tag="in_depthnumber_levels_number", input_type=Boolean(optional=True), prefix="-d", doc=InputDocumentation(doc="[int]\nDepth/Number of levels: The number of nested splits that will be tried by the algorithm")), ToolInput(tag="in_number_iterations_used_preparatory", input_type=Boolean(optional=True), prefix="-t", doc=InputDocumentation(doc="[int]\nNumber of the iterations used in the preparatory SPIN.\nDefaults to 10")), ToolInput(tag="in_feature_selection_performed", input_type=Boolean(optional=True), prefix="-f", doc=InputDocumentation(doc="[int]\nFeature selection is performed before BackSPIN. Argument controls how many genes are seleceted.\nSelection is based on expected noise (a curve fit to the CV-vs-mean plot).")), ToolInput(tag="in_width_parameter_used", input_type=Boolean(optional=True), prefix="-s", doc=InputDocumentation(doc="[float]\nControls the decrease rate of the width parameter used in the preparatory SPIN.\nSmaller values will increase the number of SPIN iterations and result in higher\nprecision in the first step but longer execution time.\nDefaults to 0.1")), ToolInput(tag="in_number_iterations_used_width", input_type=Boolean(optional=True), prefix="-T", doc=InputDocumentation(doc="[int]\nNumber of the iterations used for every width parameter.\nDoes not apply on the first run (use -t instead)\nDefaults to 8")), ToolInput(tag="in_controls_rate_parametersmaller", input_type=Boolean(optional=True), prefix="-S", doc=InputDocumentation(doc="[float]\nControls the decrease rate of the width parameter.\nSmaller values will increase the number of SPIN iterations and result in higher\nprecision but longer execution time.\nDoes not apply on the first run (use -s instead)\nDefaults to 0.3")), ToolInput(tag="in_minimal_number_genes_group_contain", input_type=Boolean(optional=True), prefix="-g", doc=InputDocumentation(doc="[int]\nMinimal number of genes that a group must contain for splitting to be allowed.\nDefaults to 2")), ToolInput(tag="in_minimal_number_cells_group_contain", input_type=Boolean(optional=True), prefix="-c", doc=InputDocumentation(doc="[int]\nMinimal number of cells that a group must contain for splitting to be allowed.\nDefaults to 2")), ToolInput(tag="in_minimum_score_has", input_type=Boolean(optional=True), prefix="-k", doc=InputDocumentation(doc="[float]\nMinimum score that a breaking point has to reach to be suitable for splitting.\nDefaults to 1.15")), ToolInput(tag="in_difference_average_expression", input_type=Boolean(optional=True), prefix="-r", doc=InputDocumentation(doc="[float]\nIf the difference between the average expression of two groups is lower than threshold the algorythm\nuses higly correlated genes to assign the gene to one of the two groups\nDefaults to 0.2")), ToolInput(tag="in_run_normal_spin", input_type=Boolean(optional=True), prefix="-b", doc=InputDocumentation(doc="[axisvalue]\nRun normal SPIN instead of backSPIN.\nNormal spin accepts the parameters -T -S\nAn axis value 0 to only sort genes (rows), 1 to only sort cells (columns) or 'both' for both\nmust be passed")), ToolInput(tag="in_verbose_print_details", input_type=Boolean(optional=True), prefix="-v", doc=InputDocumentation(doc="Verbose. Print  to the stdoutput extra details of what is happening\n"))], outputs=[ToolOutput(tag="out_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output", type_hint=File()), doc=OutputDocumentation(doc="=[outputfile]\nThe name of the file to which the output will be written"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Backspin_V0_1_0().translate("wdl", allow_empty_container=True)

